# LSFB Dataset

This library is a companion for the [French Belgian Sign Language dataset](https://lsfb.info.unamur.be/). You will find useful functions to load and manipulate the video from the LSFB dataset. Thuis library also provides scripts to download and sync the datasets.

This dataset is available under the [Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International license](https://creativecommons.org/licenses/by-nc-sa/4.0/).

The code of this library is available under the **MIT license**.

## Installation

Just type :
`python -m pip install lsfb-dataset`

## Useful links

- The code is available on [Github](https://github.com/Jefidev/lsfb-dataset)
- If you find any issue, please report them [here](https://github.com/Jefidev/lsfb-dataset/issues) 
- The full documentation of this library is available [here](https://jefidev.github.io/lsfb-dataset/)


 ## Cite

 If you use this library or the associated dataset for your research, please cite the following paper:

```
@inproceedings{Fink2021,
  doi = {10.1109/ijcnn52387.2021.9534336},
  url = {https://doi.org/10.1109/ijcnn52387.2021.9534336},
  year = {2021},
  month = jul,
  publisher = {{IEEE}},
  author = {Jerome Fink and Benoit Frenay and Laurence Meurant and Anthony Cleve},
  title = {{LSFB}-{CONT} and {LSFB}-{ISOL}: Two New Datasets for Vision-Based Sign Language Recognition},
  booktitle = {2021 International Joint Conference on Neural Networks ({IJCNN})}
}
```


